#
# spec file for package minder
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           minder
Version:        1.7.3
Release:        bp153.1.18
Summary:        Mind-mapping app
License:        GPL-3.0-or-later
Group:          Productivity/Office/Other
URL:            https://github.com/phase1geo
Source:         https://github.com/phase1geo/Minder/archive/%{version}.tar.gz#/Minder-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite) >= 5.2.3
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libmarkdown)
BuildRequires:  pkgconfig(libxml-2.0)
Recommends:     %{name}-lang

%description
A program to create, develop, visualize, organize and manage ideas.

%lang_package

%prep
%setup -q -n Minder-%{version}

# Fix: script-without-shebang
find -name \*.svg -exec chmod 0644 {} \+

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.phase1geo.minder GTK Office FlowChart
%find_lang com.github.phase1geo.minder %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/com.github.phase1geo.minder
%{_datadir}/applications/com.github.phase1geo.minder.desktop
%{_datadir}/glib-2.0/schemas/com.github.phase1geo.minder.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*.??g
%{_datadir}/metainfo/com.github.phase1geo.minder.appdata.xml
%{_datadir}/mime/packages/com.github.phase1geo.minder.xml
%{_datadir}/gtksourceview-3.0/

%files lang -f %{name}.lang

%changelog
* Thu Apr 30 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.3:
  * Updating screenshots.
  * Merge pull request #129 from Vistaus/master
  * Update LINGUAS
  * Merge branch 'devel'
* Sat Mar 28 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.7.2:
  * Fixing appdata.xml syntax issues to comply with spec.
    Updating tooltips to use Granite tooltip generator. Improving
    undo and redo tooltips.
  * Updating files for 1.7.1 release.
  * Merge branch 'devel'
  * Fixing issue with rotating link colors on main branches.
  * Merge branch 'archive_compile'
  * Merge branch 'master'
  * Fixing syntax error.
  * Checkpointing fixes for newer versions of libarchive.
  * Updating map properties screenshots.
  * Updating tool version in meson.build.
  * Merge branch 'org-mode'
  * Updating files for upcoming 1.7.0 release.
  * Updating README.md
  * Checkpointing initial work on providing Org-Mode exporting.
  * Merge branch 'portable'
  * Clearing up debug output.
  * Fixing ID mapping issue.
  * Fixing issues with pminder import extraction.
  * Checkpointing work on portable Minder exporter/importer.
  * Checkpointing work on portable minder exporter/importer.
  * Merge branch 'portable' of github.com:phase1geo/Minder into
    portable
  * Merge branch 'link_color'
  * Fixing issues with link color rooting.
  * Fixing issues with selections.
  * Added ability to select children nodes using Control-click.
  * Adding support for link color manipulation for a single node.
  * Fixing syntax error from previous checkin.
  * Fixing bug with updating tab tooltip and saving tab state
    when filename is changed.
  * Checkpointing work on parenting and re-parenting link colors.
  * Adding ability to set all selected nodes to a specific color.
    Adding ability to randomly set link colors of all selected nodes.
  * Adding map inspector switch to enable/disable automatic
    rotation of main branch link color selection.
  * Merge branch 'outliner'
  * Fixing import support of Outliner files.
  * ...
* Mon Jan 13 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.6.0:
  * Merge branch 'devel'
  * Merge branch 'note_highlighter'
  * Completing work on markdown note exporting.
  * Checkpointing export support for Markdown notes.
  * Fixing runtime warning in NodeInspector.
  * Adding libmarkdown to list of meson build dependencies.
  * Finishing work on URL support in note sidebar.
  * Checkpointing work on URL click support in note editor.
  * Checkpointing work on clicking on found URLs in notes.
  * Checkpointing work on new note markdown support.
  * Merge branch 'url'
  * Merge branch 'master' of git@github.com:phase1geo/Minder.git
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.1:
  * Create stale.yml
  * Create main.yml
  * Merge pull request #97 from Fatih20/icon-redesign
* Mon Sep  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.0:
  * Merge branch 'devel'
  * Fixing issues with appdata file for some parsers.
  * Merge branch 'master'
  * Increasing asking price from $5 to $10.
  * Updated screenshots. Updating files for new release.
  * Merge branch 'shortcuts'
  * More updates to shortcuts UI file.
  * Adding and reorganizing keyboard shortcuts to .ui file.
    Making the shortcuts window display be sensitive to the current
    state. Adding F1 as keyboard shortcut to display shortcuts
    window. Adding support for copy, cut and pasting connection title
    text. Fixing keyboard shortcut to toggle focus mode.
  * Changing shortcuts accelerator to F1.
  * Adding menu to miscellaneous header button.
  * Checkpointing work on shortcuts.ui file (now displaying
    correctly).
  * Merge branch 'node_fill'
  * Improving style handling when creating nodes.
  * Fixing issue with setting fill with link color in style
    inspector.
  * Checkpointing.
  * Adding missing file from previous commit.
  * Checkpointing initial files for creating a shortcuts window
    (not working yet).
  * Merge branch 'text_input'
  * Fixing issues with integrating GLib settings for quick entry
    spaces per tab value.
  * Checkpoint tabs per space from gsettings
  * Adding quick entry help information.
  * Fixing tab behavior in quick entry UI.
  * Adding support for Control-W shortcut to close current tab.
    Adding support for Control-E shortcut to open quick entry UI.
    Removing ability to enter space characters in leading whitespace
    within quick entry.
  * Checkpointing work on quick entry UI.
  * Fixing issues with quick entry functionality.
  * Checkpointing work on integrating new QuickEntry UI.
  * Completing work on adding PlainText import support.
  * Adding ability to read in the contents of a text file for
    importing purposes.
  * Adding undo/redo support for inserting nodes from text.
  * Finishing code that draws the text input to the canvas
    properly.
  * Starting work on text import parser.
  * Merge branch 'custom_theme'
  * Fixing issue where saved temporary theme was not marked as
    permanent.
  * More improvements to custom themes.
  * ...
* Mon Jul 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.1:
  * Merge branch 'master' of github.com:phase1geo/Minder
  * Fixing automatic layout issue.
  * Fixed spelling error in README
  * Fixing version number within meson.build.
  * Merge pull request #75 from NathanBnm/update-fr
* Thu Jul  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.0:
  * Merge branch 'devel'
  * Fixing canvas focus after adding a new tab.
  * Fixing node link icon coloring.
  * Cleaning up debug output.
  * Fixing node sizing and name positioning when tasks are
    added/removed.
  * Fixing focus button state issues.
  * Adding the development branch to the list of branches for
    Travis to build.
  * Merge branch 'focus'
  * Merge branch 'master' of git@github.com:phase1geo/Minder.git
  * Updating README installation command for Fedora users
  * Merge pull request #67 from NathanBnm/fix-post-install
- Build with granite >= 5.2.3
* Tue Jun 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.1:
  * Merge branch 'master' of github.com:phase1geo/Minder
  * Updates for new release.
  * Fixing export issue.
  * Fixing release information
* Mon May 20 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.0:
  * Fixing up small UI issues.
  * Fixing README image path.
  * Updating screenshots.
  * Fixing issue caused in last commit.
  * Improving display of style inspector when connection options
    are displayed.
  * Changing style panels to allow each subpanel to be expandable.
  * Changing the connection title box to use a rounded rectangle.
  * Adding connection padding and font styling to sidebar.
  * Updating changelist. * Initializing prefer_dark MainWindow
    setting from desktop value, if set.
  * Finishing and fixing several remaining issues with connections.
  * Checkpointing work on displaying note icon for a connection.
  * Changing the way connection titles are stored in XML.
  * Adding support for saving connection notes to XML.
  * Fixing keyboard focus when a note textbox needs to be changed.
  * Adding ability to select a connection from the current node.
  * Adding ability to select the next/previous connection.
  * Updating contextual menu items per this feature.
  * Fixing error when redoing a deleted root node.
  * Updating release information.
  * Adding ability to create a connection using the keyboard.
  * Fixing issues with displaying the current sidebar.
  * Adding keyboard support when a connection is selected.
  * Fixing issues with restoring connections after deleting.
  * ...
* Mon Apr 15 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.1:
  * Removing styling change support when affects widget is
    changed to a current node type.
  * Updating screenshot.
  * Updating appdata for the upcoming release.
  * Fixing node detach undo operation.
  * Fixing layout issue when pasting a node tree.
  * Selecting pasted node.
  * Fixing level-based styling issue. * Fixing node font styling.
  * Adding automatic style update when current-type affects are
    changed.
  * Fine-tuning arrow drawing to improve look.
  * Fixing layout issue related to tasks.
  * Fixing style inspector UI issues when changing elements in
    the inspector.
  * Merge branch 'master' of github.com:phase1geo/Minder
  * Fixing issues with scroll widgets in the style inspector in
    reference to the undo/redo buffer.
  * Merge pull request #56 from chiajlingvoj/master
  * fix reference
  * Fixing drawing issues when changing style values. * Fixing
    style inspector updating when style change are undone/redone.
  * Checkpointing work on undo buffer replace feature.
  * Adding connection styling undo/redo support.
  * Checkpointing work on reworking style undo/redo methodology.
  * A few more fixes to undo actions.
  * Fixing several issues with layout.
  * Fixing UI state of the link types widget to be disabled if
    the affected nodes do not have branches that can be changed.
  * Fixing issues with styling undo/redo
* Mon Oct 29 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.3:
  * Updating release notes.
  * Adding support for special character input.
  * Fixing syntax error in appdata.xml
  * Updating version number in Application class.
  * Updating appdata file.
* Tue Oct 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.2:
  * Adding information for 1.1.2 release
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * Updating release number.
  * Updating release information.
  * Updating release notes.
  * Fixing issues with moving nodes within a parent and attaching
    a root node into another node.
  * Reducing the minimum height of the note text area for screens
    that are shorter.
  * Fixing syntax error in appdata.xml file.
  * Updating appdata.
  * Fixing issues with editing and selecting unicode text that
    spans UTF-8 characters.
  * adjustments to README
* Mon Sep 24 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Updating application description.
  * Fixing issue where the mode property of the Node class was
    given a default value in the property.
  * Updating README with documentation link and adding libarchive
    to list of dependencies.
  * Small adjustments to some UI elements.
  * Adding missing image support for node copying.
  * Updating README.
  * Fixing compiler warning.
  * Updating screenshots.
  * Adding code to keep from scrolling infinitely.
  * Fixing a few issues after the merge.
  * Merge branch 'devel'
  * Fixed issues with calling the ImageManager cleanup method.
  * Checkpointing refactoring of ImageManager and related code.
  * Checkpointing image manager work.
  * Checkpointing (things are really broken right now).
  * Finishing image work in node inspector. * Checkpointing work
    on ImageManager.
  * Checkpointing work on ImageManager (work in progress).
  * Checkpointing.
  * Adding node resize undo action. * Fixing initial sizing of
    images to match max_width value. * Adding Vim swap files to
    gitignore file.
  * Removing ability to click on NodeInspector image to edit.
  * Adding delete and edit overlays to image in NodeInspector. *
    Fixing URI generation issue.
  * Attempting to fix popover handling for Loki.
  * Adding ability to remove image from image editor.
  * Adding support for image URI saving. * Displaying image URI
- Add pkgconfig(libarchive)
* Wed Aug  8 2018 avvissu@yandex.by
- Update to 1.0.8:
  * Adding support for opaque PNG export
  * Improving memory footprint of undo buffer.
  * Fixing issues with undoing a node attach operation.
  * Fixing issues with saving colors when an RGB value is 0.
  * Fixing CHARSET in pt_BR.po.
  * Checkpointing work on new attachment algorithm.
  * Update README.md
  * Adding overview section to README.md
  * Updating description text
  * Updating release notes
  * Checkpointing work on improving node attachment undo/redo
    functionality.
  * Fixing posx/posy original position calculation in attach
    method.
  * Starting to improve the attachment undo/redo functionality
    (work in progress).
  * Fix appadata.xml
  * Attempting to fix keyboard support in DrawArea
  * Initial attempt to fix layout issues when attaching a tree to
    another tree.
  * Updating solarized light theme.
  * Adding new Solarized Light and Solarized Dark themes.
  * Fixing issue with folding completed tasks. * Updating icons.
  * Creating icons for map inspector actions.
  * Adding button sensitivity for completed tasks and unfold all
- Add a new package with translations
* Mon Aug  6 2018 jengelh@inai.de
- Switch from imperatives to noun phrasing.
* Wed Aug  1 2018 avvissu@yandex.by
- Update to 1.0.7:
  * Changing release date for 1.0.4
  * Updating README to include double-click to edit
  * Changing update icon cache script.
  * Update.
  * Removing gtk-update-icon-cache call.
  * Another attempt to fix Travis CI issues.
  * Minor change to Travis CI.
  * Attempting to correct Travis CI failures.
  * Fixing build issues in Juno.
  * Adding GTK322 define to allow for conditional compilation.
  * Updating .pot file.
  * Minor code enhancements.
  * Fixing background color of DrawArea. * Attempting to fix use
    of obsolete Gtk.Menu.popup call in Juno.
  * Adding 1.0.3 release notes.
  * Updating pot file.
  * Cleaning up code.
  * Fixing folded assignment from with Node class.
  * Updating screenshots. * Fixing CSS handling for theme
    selection and canvas backgrounds.
  * Attempting to remove background override call in Theme class
    to instead use CSS (still having issues).
  * Modifying the search UI to a checkbutton system.
  * Adding proper support for undo functionality for
    automatically revealed nodes.
  * Attempting to fix how folded nodes are handled.
  * Adding updated search criteria items. * Adjusting margins
    within popover menus. * Several enhancments to search UI.
  * Updating screenshots.
  * Changing properties icon in header to pane show/hide icons.
* Sun Jul  1 2018 avvissu@yandex.by
- Initial package
